#
# spec file for package piglit
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%ifarch %arm aarch64
# Enable openGL ES only
%bcond_with opengl
%bcond_without opengles
%else
# Enable openGL and openGL ES
%bcond_without opengl
%bcond_without opengles
%endif

Name:           piglit
Version:        1~20170607.bc6ef16df
Release:        lp150.2.8
Summary:        OpenGL driver testing framework
License:        MIT
Group:          System/Benchmark
Url:            http://cgit.freedesktop.org/piglit
Source0:        %{name}-%{version}.tar.xz
Source1:        piglit-rpmlintrc
Source2:        suse_qa.py
Source3:        suse_qa-skip-tests.txt
Source4:        opensuse_qa.py
Source5:        opensuse_qa-skip-tests.txt
BuildRequires:  cmake
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  glibc-devel
BuildRequires:  pkgconfig
BuildRequires:  python3
BuildRequires:  python3-Mako
BuildRequires:  python3-numpy
BuildRequires:  python3-six
BuildRequires:  python3-xml
BuildRequires:  waffle-devel
BuildRequires:  pkgconfig(egl)
%if %{with opengl}
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(glproto)
BuildRequires:  pkgconfig(glu)
%endif
%if %{with opengles}
BuildRequires:  Mesa-libGLESv3-devel
BuildRequires:  pkgconfig(glesv1_cm)
BuildRequires:  pkgconfig(glesv2)
%endif
BuildRequires:  pkgconfig(libdrm)
%ifarch x86_64
BuildRequires:  pkgconfig(libdrm_intel)
%endif
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xcb)
BuildRequires:  pkgconfig(xcb-dri2)
BuildRequires:  pkgconfig(xcb-dri3)
Requires:       python3
Requires:       python3-Mako
Requires:       python3-numpy
Requires:       python3-six
Requires:       python3-xml
ExcludeArch:    %{ix86} ppc

%description
Piglit is a collection of automated tests for OpenGL and OpenCL
implementations.

The goal of Piglit is to help improve the quality of open source
OpenGL drivers by providing developers with means to perform
regression tests.

It contains the Glean tests, some tests adapted from Mesa, as well as
some specific regression tests for certain bugs. HTML summaries can
be generated, including the ability to compare different test runs.

%prep
%setup -q

%build
# FIXME: you should use %%cmake macros
# Note: Using the cmake rpm macro to get good defaults for installation
# directories, CFLAGS etc. Some changes on top:
# Note: Overwriting CMAKE_SHARED_LINKER_FLAGS with those from the cmake macro,
# but leaving out -Wl,--no-undefined
# Note: Overwriting CMAKE_SKIP_RPATH to be off,  but enabling
# CMAKE_BUILD_WITH_INSTALL_RPATH so the individual test binaries in
# /usr/lib64/piglit/bin/* can find the libraries in /usr/lib64/piglit/lib
%cmake \
%if %{without opengl}
  -DPIGLIT_BUILD_GL_TESTS=OFF \
%endif
%if %{without opengles}
  -DPIGLIT_BUILD_GL_ES1_TESTS=OFF \
  -DPIGLIT_BUILD_GL_ES2_TESTS=OFF \
  -DPIGLIT_BUILD_GL_ES3_TESTS=OFF \
%endif
  -DCMAKE_SHARED_LINKER_FLAGS="-Wl,--as-needed -Wl,-z,now" \
  -DCMAKE_SKIP_RPATH:BOOL=OFF \
  -DCMAKE_BUILD_WITH_INSTALL_RPATH:BOOL=ON
make %{?_smp_mflags}

%install
%cmake_install

install -D -m 644 %{SOURCE2} %{buildroot}%{_libdir}/piglit/tests
install -D -m 644 %{SOURCE3} %{buildroot}%{_libdir}/piglit/tests
install -D -m 644 %{SOURCE4} %{buildroot}%{_libdir}/piglit/tests
install -D -m 644 %{SOURCE5} %{buildroot}%{_libdir}/piglit/tests
%fdupes %{buildroot}/%{_libdir}/piglit

%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%files
%defattr(-,root,root)
%{_libdir}/piglit
%{_bindir}/piglit
%doc %{_datadir}/doc/piglit

%changelog
* Tue Mar 27 2018 guillaume.gardet@opensuse.org
- Fix SOURCE5 installation
- Handle properly openGL and openGL ES tests
- Enable Build for %%arm and AArch64
* Thu Jun  8 2017 mimi.vx@gmail.com
- Update to version 1~20170607.bc6ef16df:
  * arb_shader_storage_buffer_object: add member-memory-qualifiers.frag
  * arb_bindless_texture: add arrays-of-struct.frag compiler tests
  * arb_bindless_texture: add struct-inside-uniform-block.frag compiler tests
  * cl: Add array of structures to program-scope-arrays test
  * cl: Add input dependent test for global_offset
  * egl: API test for EGL_IMG_context_priority extension
  * egl-context-priority: Check eglInitialize result.
  * primitive-restart: run all tests even when there's a failure
  * srgb_conformance: fix error computation
  * util: support instancing with piglit_draw_rect_custom
  * shader_runner: add "draw instanced rect ortho" commands
  * arb_tessellation_shader: test instancing
  * glsl-1.50: test instancing with a geometry shader
  * arb_tessellation_shader: add 3 new trivial tess+gs tests
  * arb_compute_shader: test shaders when only 1 channel of gl_WorkGroupID is used
  * drawoverhead: new microbenchmark
  * shader_runner: add "draw arrays instanced" command
  * shader_runner: add "relative probe rect rgba" command
  * arb_tessellation_shader: test gl_PrimitiveID in instanced draws
  * glsl-1.50: test gl_PrimitiveID in fragment shader when instancing is used
  * util: add MIN3/MAX3 convenience macros
  * arb_sparse_buffer: minmax test
  * arb_sparse_buffer: add basic rendering test
  * arb_sparse_buffer: add an extended commit test
  * arb_sparse_buffer: add tests for various *BufferSubData commands
  * piglit-framework-gl: add KHR_no_error enum to piglit_gl_test_config
  * piglit-framework-gl: skip tests incompatible with KHR_no_error
  * shader_runner: mark as compatible with KHR_no_error testing
  * framework: Add command.setter method to Test
  * tests: add no_error test profile for testing KHR_no_error
  * tests: mark KHR_no_error incompatible tests
  * tests: mark KHR_no_error compatible tests
  * textureSamples: fix printf
  * piglit-framework-gl: add piglit_khr_no_error for detecting when khr_no_error enabled
  * arb_direct_state_access: set KHR_no_error compatibility
  * KHR_no_error: set compatibility status for a bunch of glCompressedTex* tests
  * arb_framebuffer_object: set KHR_no_error compatibility
  * arb_copy_buffer: set KHR_no_error compatibility
  * arb_draw_buffers_blend: set KHR_no_error compatibility
  * arb_compute_variable_group_size: set KHR_no_error compatibility
  * arb_compute_shader: remove misleading headers
  * arb_compute_shader: set KHR_no_error compatibility
  * texturing: Add decompression test for S3TC DXT1
  * arb_bindless_texture: add missing writeonly qualifier to images/inout.frag
  * arb_bindless_texture: add new execution tests with sampler/image arrays
  * shader_runner: add support for setting resident handles to UBO
  * arb_bindless_texture: add ubo-named-block execution tests
  * arb_uniform_buffer_object: add uniform-block-memory-qualifier.frag
  * arb_direct_state_access: Fix memory leaks.
  * arb_sparse_buffer: Fix Coverity unintentional integer overflow defect.
  * cl-api-get-platform-ids: Remove duplicate piglit_cl_check_error.
  * shader_runner: clear resident handles before texture bindings
  * shader_runner: only clear handles that are resident
  * arb_bindless_texture: add new explicit-image-binding.shader_test
  * arb_bindless_texture: fix setting bound/bindless uniforms
  * parser_utils: do not overwrite value when no digits are found
  * shaders/ssa: fix wrong syntax in fs-swap-problem.shader_test
  * shaders: set missing blue color to glsl-const-builtin-distance.shader_test
  * arb_gpu_shader_fp64: set missing 'w' component to glsl-uniform-initializer-4
  * test/gleantest: fix missing --quick property from quick profile
  * test_gleantest: make sure --quick is returned when set in GLOBAL_PARAMS
  * glean: remove test_uniform_multiple_samplers()
  * genned-names: correct the parameter for glBindBufferRange
  * tests: Update integration for khronos CTS runner.
  * util/egl: Honour Surfaceless MESA in get_default_display
  * egl_mesa_platform_surfaceless: Don't use eglGetPlatformDisplay directly
  * egl_mesa_platform_surfaceless: Use EXT functions for surfaces
  * arb_base_instance: set KHR_no_error compatibility
  * gl-4.4: set KHR_no_error compatibility
  * arb_uniform_buffer_object: set KHR_no_error compatibility
  * arb_draw_indirect: set KHR_no_error compatibility
  * arb_indirect_parameters: set KHR_no_error compatibility
  * arb_shader_atomic_counters: set KHR_no_error compatibility
  * arb_shader_storage_buffer_object: set KHR_no_error compatibility
  * arb_get_program_binary: check correctly got_error
  * arb_texture_view: add simple test for rendering to R32UI texture view
  * arb_shader_image_load_store: set KHR_no_error compatibility
  * egl_khr_create_context: Don't expect GL_CONTEXT_FLAGS query to work when it cannot
  * fbo: Fix trivial typo in comment
  * fbo: Require ARB_depth_texture in more tests
  * getteximage-depth: Require ARB_depth_texture
  * texsubimage-depth-formats: Require ARB_depth_texture
  * fbo: Remove support for the checkerboard test pattern
  * fbo: Use renderbuffers instead of textures
  * teximage-errors: Only run the depth texture subtests when depth textures are supported
  * teximage-errors: Fix comment formatting after previous commit
  * glx_ext_import_context: fix comment typo
  * ext_framebuffer_multisample: fix comment typo
  * ARB_invalidate_subdata: set KHR_no_error status
  * gl-3.2/layered-rendering: set KHR_no_error status
  * texturing/tex3d-maxsize: set KHR_no_error status
  * TexSubImage1D tests: set KHR_no_error status
  * gl-2.0/vertex-const-attr: fix comment typo
  * CMake: define GBM_BO_MAP only when symbol is found
  * arb_bindless_texture: add new compiler tests for struct with image arrays
* Sat Apr 29 2017 mpluskal@suse.com
- Update to version 1~20170428.dc7571028:
  * gl-4.5/compare-framebuffer-parameter-with-get: add test
  * arb_vertex_buffer_object-combined-vertex-index: new VBO test
  * tests: INTEL_conservative_rasterization: add missing gles3 build file
  * cl: Add sign_extend_inreg test
  * framework/results.py: Copy 'tests' internally to OrderedDict
  * framework/backends/json.py: preserve 'tests' order
  * Add a test for GL_EXT_frag_depth
  * gl-4.5/compare-framebuffer-parameter-with-get: Fix return-type warning.
  * gl-4.5: Fix tautological-compare warning.
  * arb_shader_storage_buffer_object: test unsized vs implicit arrays. This tests the difference between an unsized and an implicitly sized array
  * arb_texture_multisample/minmax: Indent according to piglit style.
  * arb_texture_multisample/minmax: Don't check INTEGER without integer textures.
  * arb_get_texture_sub_image-errors: Fix expected error values
  * gl-4.5: Fix sometimes-uninitialized warning.
  * gles-es-3.10: unsized-array-not-in-last-position
  * glsl-shaders: test correct shader source is use on cache fallback
  * draw-elements: test glMultiDrawElements(GL_UNSIGNED_BYTE)
  * all.py: let VBO tests run concurrently
  * Add arb_transform_feedback_overflow_query tests.
  * arb_transform_feedback_overflow_query: add error tests.
  * primitive-restart: Delete more glDrawArrays tests.
  * arb_transform_feedback_overflow_query: skip QBO subtests if unsupported
  * generated_tests: fix tessellation -> tesselation typo
  * generated_tests: Fix require_extensions for constant_array_size
  * arb_gpu_shader_fp64: fix vs-double-uniform-array-direct-indirect
  * get-active-attrib-array: allocate a sufficiently large buffer
  * builtin_functions: Add more 64-bit integers
  * arb_gpu_shader_fp64: add non-uniform control flow test for indirect addressing
  * shader_runner: make buffer large enough to fit any GL enum
  * arb_shading_language_420pack: check different binding points
  * arb_shader_atomic_counters: check different binding points
  * README: correct flags for 32-on-64 build
  * glsl-1.30: Test large local array (v2)
  * glsl-1.30: Test large vec4 local array
  * glsl-1.30: Test large vec2 local array
  * glsl-1.30: Test large local vec3 array
  * glsl-1.30: Test multiple large local arrays
  * Set non-mipmap filter for CopyImage textures in namespace pollution test
  * Set nearest filter for CopyImage textures in api errors test.
  * arb_vertex_attrib_64bit: remove piglit_ortho_projection() call
  * shader_runner: Add support for "polygon mode"
  * nv_fill_rectangle: add tests
  * arb_shader_ballot: simple ballotARB execution test
  * arb_shader_ballot: add readInvocationARB tests
  * arb_shader_ballot: add readFirstInvocationARB test
  * arb_shader_ballot: test builtin variables
  * arb_shader_ballot: test ballotARB inside if/else control flow
  * arb_shader_ballot: test peeling away the first invocation
  * arb_shader_clock: add basic execution tests
  * arb_cull_distance: Fix sometimes-uninitialized warnings.
  * glslparsertest: Add test case for FDO bug #100438.
  * cl: Unmap mapped cl buffer in buffer-flags test
  * cl: OCL1.1 allows pointers to NULL as valid kernel args
  * glsl-1.50: instance name is not used to match UBO/SSBOs shader interfaces
  * arb_texture_buffer_range: test glTexBufferRange() with wrong target
  * tests/py_modules/constants.py: look for generated_tests in build dir (v2)
  * glsl-1.10: tests return lowering for a loop nested in an if
  * shader_runner: add support for ARB_bindless_texture
  * add API-related tests for ARB_bindless_texture
  * arb_bindless_texture: add compiler-related tests
  * arb_bindless_texture: add linker-related tests
  * arb_bindless_texture: add execution-related tests
  * arb_post_depth_coverage-basic: Add a basic initial test.
  * arb_post_depth_coverage-multisampling: Add a multisampling test.
  * arb_post_depth_coverage-sample-shading: Test sample shading.
  * framework/exceptions: Add an exception class for user errors
  * framework: Exit if a filter removes all tests from a profile
  * Cmake: install comp shaders that are not generated
  * glsl-1.50: new trivial GS test
  * arb_tessellation_shader/execution/trivial: new trivial tess test
  * arb_tessellation_shader/execution/sanity2: new variant of the test
  * arb_blend_func_extended/output-location: require GLSL 1.50
  * arb_enhanced_layouts/component-layout: require GLSL 1.50
  * arb_separate_shader_objects/atomic-counter: require GLSL 1.50
  * arb_shader_draw_parameters: require GLSL 3.30
  * tests/egl: report 'skip' instead of 'fail' if not running under X
  * arb_bindless_texture: Fix memory leaks.
  * gl-1.4: test some glMultiDrawArrays error conditions
  * arb_gpu_shader_int64: add bit-shift tests
  * arb_draw_indirect: add transform-feedback test
  * arb_enhanced_layouts: add test for location aliasing across GS vertex streams
  * arb_shading_language_420pack: test binding different sampler types to the same tex unit
  * arb_enhanced_layouts: Remove unused variable.
  * arb_separate_shader_objects: Check piglit_link_check_status result.
  * glsl-1.40: Print the same expected output used in comparison.
  * gl-1.0-simple-renderbuffer: add a protection from test failure when an user fbo is defined
  * gl-1.0-simple-renderbuffer: fix indentation issues (trivial)
  * arb_fragment_shader_interlock: Test image load/store.
  * framework/test/shader_test: use -fbo option for shader tests
  * glx: add test for drawing to GL_FRONT between glXMakeCurrent()
  * all.py: s/OpenGL 1.1/opengl 1.1/
  * arb_fragment_shader_interlock: fix MinGW build
  * arb_shader_image_load_store: add format-layout-with-non-image-type.frag compiler test
  * arb_shader_image_load_store: add memory-qualifier-with-non-image-type.frag
  * shader_runner: clean up resident handles at exit time
  * arb_bindless_texture: add uniform-block-initializer.frag compiler tests
  * arb_bindless_texture: fix images/inout.frag
  * arb_bindless_texture: consolidate inout-*.frag compiler tests
  * arb_bindless_texture: add inout-non-matching-type.frag compiler tests
  * arb_bindless_texture: add explicit-texture-binding.shader_test
  * arb_bindless_texture: separate execution tests into two directories
* Thu Feb 16 2017 jengelh@inai.de
- Update description
* Thu Feb 16 2017 mpluskal@suse.com
- Build only on 64 bit architectures
* Wed Feb  8 2017 mimi.vx@gmail.com
- Update to version 1~20170207.5bbeed390:
  * framework/test/glsl_parser_test.py: fix python script to run glslparsertest on Windows
  * arb_gpu_shader_int64: allow shift tests to be generated
  * arb_gpu_shader_int64: add testing of unsigned div/mod
* Mon Feb  6 2017 mimi.vx@gmail.com
- Update to version 1~20170203.ca58eec0b:
  * CMake: Enable python 3.6
  * glsl-1.20: add a test that gl_ClipVertex actually affects all primitive types
  * glsl-1.30: add a test that gl_ClipDistance actually affects all primitive types
  * cl: Add tests for fdiv with neg/abs inputs
  * cl: Add tests for stored fneg
  * getteximage-formats: Disable dithering during glDrawPixels
  * framework/backends/json: always flush the metadata to the disk
  * egl: test that EGL_BAD_PARAMETER is returned for an invalid EGLImage attrib
  * Rename gen_conversion_fp64 to gen_conversion
  * gen_conversion: explicitly enumerate conversion target types
  * gen_conversion: rename _gen_from/to_double and _double_type
  * gen_conversion: refactor templates to allow multiple extensions
  * gen_conversion: generate tests for 64-bit integers
  * framework/programs/run.py: Allow comments in test-list files.
  * arb_texture_view-texsubimage-levels: correct buffer size
  * util: move SUBTEST and SUBTESTCONDITION to piglit-util
  * gl-3.1/draw-buffer-errors: skip if current Context is > 4.0
  * gl-3.1/draw-buffers-errors: select explicitly default framebuffer
  * gl-4.5/named-framebuffer-draw-buffers-errors: add a new test
  * gl-4.5/named-framebuffer-read-buffer-errors: add test
  * polygon-offset: draw tests in two rows of nine
  * gl-1.4-polygon-offset: print more info on failure.
* Mon Jan 23 2017 mimi.vx@gmail.com
- Update to version 1~20170120.9123cb73c:
  * Test multiple inout parameters with indirect array indexing
  * Test multiple inout parameters with arrays of arrays
* Fri Jan 20 2017 mimi.vx@gmail.com
- Update to version 1~20170119.9861294a9:
  * unittests: Add new python generator to unittests
  * CI: Add python 3.6 to build matrix
* Thu Jan 19 2017 mimi.vx@gmail.com
- Update to version 1~20170119.1004a07bb:
  * egl_khr_gl_image: Add test that clears a shared image
  * glsl-1.10: test min max optimisation pass
  * glsl-1.10: another test for min max optimisation pass
  * deqp: Search stdout and stderr for X connection failure
  * Add GL_INTEL_conservative_rasterization tests
  * generated_tests: new compiler tests for INTEL_conservative_rasterization
  * resume: use the previously-set test-list when resuming
  * shader_runner: Fix MSVC build error.
  * arb_texture_view: Fix MSVC build.
  * PNG files, write mode correction
* Mon Jul 11 2016 msrb@suse.com
- Update to latest version.
